.. _gwpy-examples:

#############
GWpy examples
#############

.. toctree::
   :maxdepth: 2

   timeseries/index

   signal/index

   frequencyseries/index

   spectrogram/index

   segments/index

   table/index

   miscellaneous/index
